//----------------------------------------------------------------------
// fraction1.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const euclid = require('./euclid.js');

function create(num=0, den=1) {

   if (arguments.length > 2)
      throw new Error('Too many arguments');

   if (den === 0)
      throw new Error('Denominator cannot be zero');

   let f = {};

   f._num = num;
   f._den = den;

   if (f._den < 0) {
      f._num *= -1;
      f._den *= -1;
   }
   if (f._num === 0)
      f._den = 1;
   else {
      let gcden = euclid.gcd(f._num, f._den);
      f._num /= gcden;
      f._den /= gcden;
   }

   return f;
}

function toString(f1) {
   return String(f1._num) + '/' + String(f1._den);
}

function compareTo(f1, f2) {
   if ((f1._num * f2._den) < (f2._num * f1._den))
      return -1;
   if ((f1._num * f2._den) > (f2._num * f1._den))
      return 1;
   return 0;
}

function negate(f1) {
   return create(-f1._num, f1._den);
}

function add(f1, f2) {
   let newNum = (f1._num * f2._den) + (f2._num * f1._den);
   let newDen = f1._den * f2._den;
   return create(newNum, newDen);
}

function subtract(f1, f2) {
   let newNum = (f1._num * f2._den) - (f2._num * f1._den);
   let newDen = f1._den * f2._den;
   return create(newNum, newDen);
}

function multiply(f1, f2) {
   let newNum = f1._num * f2._num;
   let newDen = f1._den * f2._den;
   return create(newNum, newDen);
}

function divide(f1, f2) {
   let newNum = f1._num * f2._den;
   let newDen = f1._den * f2._num;
   return create(newNum, newDen);
}

module.exports = { create, toString, compareTo, negate, add,
   subtract, multiply, divide };
