//----------------------------------------------------------------------
// fraction1client.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const readlineSync = require('readline-sync');
const fraction = require('./fraction1.js');

//----------------------------------------------------------------------

function readInt(prompt) {
   let line = readlineSync.question(prompt);
   if (line === '')
      throw new Error('Missing integer');
   if (isNaN(line))
      throw new Error('Not a number');
   let n = Number(line);
   if (! Number.isInteger(n))
      throw new Error('Not an integer');
   return n;
}

//----------------------------------------------------------------------

function main() {
   try {
      let n1 = readInt('Numerator 1: ');
      let d1 = readInt('Denominator 1: ');
      let n2 = readInt('Numerator 2: ');
      let d2 = readInt('Denominator 2: ');

      let f1 = fraction.create(n1, d1);
      let f2 = fraction.create(n2, d2);

      process.stdout.write('f1: ' + fraction.toString(f1) + '\n');
      process.stdout.write('f2: ' + fraction.toString(f2) + '\n');

      if (f1 === f2)
         process.stdout.write('f1 is identical to f2\n');
      else
         process.stdout.write('f1 is not identical to f2\n');

      let compare = fraction.compareTo(f1, f2);
      if (compare < 0)
         process.stdout.write('f1 is less than f2\n');
      if (compare > 0)
         process.stdout.write('f1 is greater than f2\n');
      if (compare === 0)
         process.stdout.write('f1 is equal to f2\n');

      let f3;

      f3 = fraction.negate(f1);
      process.stdout.write('-f1: ' + fraction.toString(f3) + '\n');

      f3 = fraction.add(f1, f2);
      process.stdout.write('f1 + f2: ' + fraction.toString(f3) + '\n');

      f3 = fraction.subtract(f1, f2);
      process.stdout.write('f1 - f2: ' + fraction.toString(f3) + '\n');

      f3 = fraction.multiply(f1, f2);
      process.stdout.write('f1 * f2: ' + fraction.toString(f3) + '\n');

      f3 = fraction.divide(f1, f2);
      process.stdout.write('f1 / f2: ' + fraction.toString(f3) + '\n');
   }
   catch (e) {
      process.stderr.write(String(e) + '\n');
   }
}

if (require.main === module)
   main();
