//----------------------------------------------------------------------
// fraction2.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const euclid = require('./euclid.js');

function createFraction(num=0, den=1)
{
   if (arguments.length > 2)
      throw new Error('Too many arguments');

   if (den === 0)
      throw new Error('Denominator cannot be zero');

   let f = {};

   f._num = num;
   f._den = den;

   if (f._den < 0) {
      f._num *= -1;
      f._den *= -1;
   }
   if (f._num === 0)
      f._den = 1;
   else {
      let gcden = euclid.gcd(f._num, f._den);
      f._num /= gcden;
      f._den /= gcden;
   }

   f.toString = function() {
      return String(this._num) + '/' + String(this._den);
   };

   f.compareTo = function(other) {
      if ((this._num * other._den) < (other._num * this._den))
         return -1;
      if ((this._num * other._den) > (other._num * this._den))
         return 1;
      return 0;
   };

   f.negate = function() {
      return createFraction(-this._num, this._den);
   };

   f.add = function(other) {
      let newNum = (this._num * other._den) + (other._num * this._den);
      let newDen = this._den * other._den;
      return createFraction(newNum, newDen);
   };

   f.subtract = function(other) {
      let newNum = (this._num * other._den) - (other._num * this._den);
      let newDen = this._den * other._den;
      return createFraction(newNum, newDen);
   };

   f.multiply = function(other) {
      let newNum = this._num * other._num;
      let newDen = this._den * other._den;
      return createFraction(newNum, newDen);
   };

   f.divide = function(other) {
      let newNum = this._num * other._den;
      let newDen = this._den * other._num;
      return createFraction(newNum, newDen);
   };

   return f;
}

module.exports = { createFraction };
