//----------------------------------------------------------------------
// fraction5client.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const readlineSync = require('readline-sync');
const fraction = require('./fraction5.js');

//----------------------------------------------------------------------

function readInt(prompt) {
   let line = readlineSync.question(prompt);
   if (line === '')
      throw new Error('Missing integer');

   let n = Number(line);
   if (! Number.isInteger(n))
      throw new Error('Not an integer');

   return n;
}

//----------------------------------------------------------------------

function main() {
   try {
      let n1 = readInt('Numerator 1: ');
      let d1 = readInt('Denominator 1: ');
      let n2 = readInt('Numerator 2: ');
      let d2 = readInt('Denominator 2: ');

      let f1 = new fraction.Fraction(n1, d1);
      let f2 = new fraction.Fraction(n2, d2);

      process.stdout.write('f1: ' + f1.toString() + '\n');
      process.stdout.write('f2: ' + String(f2) + '\n');

      if (f1 === f2)
         process.stdout.write('f1 is identical to f2\n');
      else
         process.stdout.write('f1 is not identical to f2\n');

      let compare = f1.compareTo(f2);
      if (compare < 0)
         process.stdout.write('f1 is less than f2\n');
      if (compare > 0)
         process.stdout.write('f1 is greater than f2\n');
      if (compare === 0)
         process.stdout.write('f1 is equal to f2\n');

      let f3;

      f3 = f1.negate();
      process.stdout.write('-f1: ' + String(f3) + '\n');

      f3 = f1.add(f2);
      process.stdout.write('f1 + f2: ' + String(f3) + '\n');

      f3 = f1.subtract(f2);
      process.stdout.write('f1 - f2: ' + String(f3) + '\n');

      f3 = f1.multiply(f2);
      process.stdout.write('f1 * f2: ' + String(f3) + '\n');

      f3 = f1.divide(f2);
      process.stdout.write('f1 / f2: ' + String(f3) + '\n');
   }
   catch (e) {
      process.stderr.write(e + '\n');
   }
}

if (require.main === module)
   main();
